@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 
 ###############################################################################
@@ -243,7 +243,14 @@ These methods are explained in detail in L<Excel::Writer::XLSX::Chart>. Class sp
 
 =head1 Bar Chart Methods
 
-There aren't currently any bar chart specific methods. See the TODO section of L<Excel::Writer::XLSX::Chart>.
+The C<Bar> chart module also supports the following sub-types:
+
+    stacked
+    percent_stacked
+
+These can be specified at creation time via the C<add_chart()> Worksheet method:
+
+    my $chart = $workbook->add_chart( type => 'bar', subtype => 'stacked' );
 
 =head1 EXAMPLE
 
